Welcome to PyNOT : Identify

#### Start-up

First, load a 2D calibration lamp spectrum (arc frame) by pressing the Load Spectrum button or using the keyboard shortcut 'cmd + O' (if on Mac, otherwise use 'control + O'). The 1D spectrum is by default constructed from the central 3 rows. If you want to determine the wavelength solution for a different location along the slit, you can specify the '--loc' option when starting PyNOT identify. You can also change this from the menu "File > Set 1D Location" (see section Manage 2D Image below).

#### Loading a Line List

If the line list is not automatically loaded, you have to load it by pressing the Load Line List button. For NOT/ALFOSC there are only two options, Helium-Neon (HeNe_linelist) or Thorium-Argon (ThAr_linelist), both are given in vacuum wavelengths. Alternatively, you can locate your own line list. If the line list you want to load is given in air wavelengths, you have to manually switch the Ref. Type in the upper right corner to air. Alternatively, you can put the following line in the top of the line list file: '# ref = air', which automatically sets the right reference type.

#### Loading a Pixel Table

If an existing pixel table already exists, you can load it by clicking the Load PixTable button. In this case, there might be small shifts between the previously tabulated lines and the given arc frame. You can then re-fit the lines either one-by-one by clicking the Refit Line button and clicking on the line to re-fit, or by clicking on the Refit All button.

#### Identifying Lines

Identify reference lines by clicking on the plotting view (right-hand side) and hitting the A key or the Add Line button on the top row (make sure to have your reference line map at hand). Then click on the position of the emission line you want to identify. The program will then fit the centroid of the line and mark it by a vertical dashed line. The fitted position shows up in the Pixel Table (middle panel). The input area of the given line will then be highlighted for you to give the reference wavelength. The wavelength just has to be given approximately (within 5 Å) and the exact wavelength will be looked up using the Reference Line List.

#### Air to Vacuum Conversion

The wavelength solution in PyNOT is by default calculated in a vacuum reference frame. If instead you want to convert the wavelengths to air (or vice versa), you can toggle the conversion by clicking the menu "Edit > Toggle Air <-> Vacuum Conversion".

#### Manage 2D Image

The location along the slit where the arc line spectrum is extracted can be changed by going to the menu "File > Set 1D Location". Here the loaded 2D image can also be flipped, if the axes are not aligned correctly.

#### Fitting the Wavelength Solution

Once a number of lines has been identified, you can fit the wavelength solution with a polynomium by clicking on the Fit button (cmd + F). The default order is 3, change this by typing in the field marked Polynomial Order. You can inspect the residuals of the fit by clicking the Residual/Data button.
The dispersion of the best-fit solution is shown in the upper right corner of the wavelength solution plot (as σλ).
Once a solution has been fitted, the wavelength of newly added lines will automatically be estimated from the fit. Wrongly identified lines or outliers can be removed by clicking the Delete Line button on the top row and then clicking on the vertical red line to be removed.

#### Saving the Pixel Table

When you are happy with a wavelength solution, save the corresponding pixel table by clicking Done.